@@ -20,10 +20,22 @@ class ApiGatewayV2HttpApi(Resource):
         "FailOnWarnings": GeneratedProperty(),
         "DisableExecuteApiEndpoint": GeneratedProperty(),
         "BasePath": GeneratedProperty(),
+        "Tags": GeneratedProperty(),
         "CorsConfiguration": GeneratedProperty(),
     }
 
     runtime_attrs = {"http_api_id": lambda self: ref(self.logical_id)}
+    Tags: Optional[PassThrough]
+
+    def assign_tags(self, tags: Dict[str, Any]) -> None:
+        """Overriding default 'assign_tags' function in Resource class
+
+        Function to assign tags to the resource
+        :param tags: Tags to be assigned to the resource
+
+        """
+        if tags is not None and "Tags" in self.property_types:
+            self.Tags = tags
 
 
 class ApiGatewayV2Stage(Resource):
@@ -42,6 +54,17 @@ class ApiGatewayV2Stage(Resource):
     }
 
     runtime_attrs = {"stage_name": lambda self: ref(self.logical_id)}
+    Tags: Optional[PassThrough]
+
+    def assign_tags(self, tags: Dict[str, Any]) -> None:
+        """Overriding default 'assign_tags' function in Resource class
+
+        Function to assign tags to the resource
+        :param tags: Tags to be assigned to the resource
+
+        """
+        if tags is not None and "Tags" in self.property_types:
+            self.Tags = tags
 
 
 class ApiGatewayV2DomainName(Resource):
@@ -56,7 +79,17 @@ class ApiGatewayV2DomainName(Resource):
     DomainName: Intrinsicable[str]
     DomainNameConfigurations: Optional[List[Dict[str, Any]]]
     MutualTlsAuthentication: Optional[Dict[str, Any]]
-    Tags: Optional[Dict[str, Any]]
+    Tags: Optional[PassThrough]
+
+    def assign_tags(self, tags: Dict[str, Any]) -> None:
+        """Overriding default 'assign_tags' function in Resource class
+
+        Function to assign tags to the resource
+        :param tags: Tags to be assigned to the resource
+
+        """
+        if tags is not None and "Tags" in self.property_types:
+            self.Tags = tags
 
 
 class ApiGatewayV2ApiMapping(Resource):
@@ -75,7 +108,7 @@ JwtConfiguration = Dict[str, Union[str, List[str]]]
 
 
 class ApiGatewayV2Authorizer:
-    def __init__(  # type: ignore[no-untyped-def] # noqa: too-many-arguments
+    def __init__(  # type: ignore[no-untyped-def] # noqa: PLR0913
         self,
         api_logical_id=None,
         name=None,
@@ -88,6 +121,7 @@ class ApiGatewayV2Authorizer:
         authorizer_payload_format_version=None,
         enable_simple_responses=None,
         is_aws_iam_authorizer=False,
+        enable_function_default_permissions=None,
     ):
         """
         Creates an authorizer for use in V2 Http Apis
@@ -95,7 +129,9 @@ class ApiGatewayV2Authorizer:
         self.api_logical_id = api_logical_id
         self.name = name
         self.authorization_scopes = authorization_scopes
-        self.jwt_configuration: Optional[JwtConfiguration] = self._get_jwt_configuration(jwt_configuration)
+        self.jwt_configuration: Optional[JwtConfiguration] = self._get_jwt_configuration(
+            jwt_configuration, api_logical_id
+        )
         self.id_source = id_source
         self.function_arn = function_arn
         self.function_invoke_role = function_invoke_role
@@ -103,6 +139,7 @@ class ApiGatewayV2Authorizer:
         self.authorizer_payload_format_version = authorizer_payload_format_version
         self.enable_simple_responses = enable_simple_responses
         self.is_aws_iam_authorizer = is_aws_iam_authorizer
+        self.enable_function_default_permissions = enable_function_default_permissions
 
         self._validate_input_parameters()
 
@@ -115,6 +152,13 @@ class ApiGatewayV2Authorizer:
         if authorizer_type == "REQUEST":
             self._validate_lambda_authorizer()
 
+        if enable_function_default_permissions is not None:
+            sam_expect(
+                enable_function_default_permissions,
+                api_logical_id,
+                f"Authorizers.{name}.EnableFunctionDefaultPermissions",
+            ).to_be_a_bool()
+
     def _get_auth_type(self) -> str:
         if self.is_aws_iam_authorizer:
             return "AWS_IAM"
@@ -166,6 +210,11 @@ class ApiGatewayV2Authorizer:
                 self.api_logical_id, "EnableSimpleResponses must be defined only for Lambda Authorizer."
             )
 
+        if self.enable_function_default_permissions is not None and authorizer_type != "REQUEST":
+            raise InvalidResourceException(
+                self.api_logical_id, "EnableFunctionDefaultPermissions must be defined only for Lambda Authorizer."
+            )
+
     def _validate_jwt_authorizer(self) -> None:
         if not self.jwt_configuration:
             raise InvalidResourceException(
@@ -297,7 +346,9 @@ class ApiGatewayV2Authorizer:
         return identity_source
 
     @staticmethod
-    def _get_jwt_configuration(props: Optional[Dict[str, Union[str, List[str]]]]) -> Optional[JwtConfiguration]:
+    def _get_jwt_configuration(
+        props: Optional[Dict[str, Union[str, List[str]]]], api_logical_id: str
+    ) -> Optional[JwtConfiguration]:
         """Make sure that JWT configuration dict keys are lower case.
 
         ApiGatewayV2Authorizer doesn't create `AWS::ApiGatewayV2::Authorizer` but generates
@@ -312,8 +363,8 @@ class ApiGatewayV2Authorizer:
 
         Parameters
         ----------
-        props
-            jwt configuration dict with the keys either lower case or capitalized
+        props: jwt configuration dict with the keys either lower case or capitalized
+        api_logical_id: logical id of the Serverless Api resource with the jwt configuration
 
         Returns
         -------
@@ -321,4 +372,5 @@ class ApiGatewayV2Authorizer:
         """
         if not props:
             return None
+        sam_expect(props, api_logical_id, "JwtConfiguration").to_be_a_map()
         return {k.lower(): v for k, v in props.items()}
